intelmq.bots.experts.asn_lookup package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.asn_lookup package

## Submodules

## intelmq.bots.experts.asn_lookup.expert module

class intelmq.bots.experts.asn_lookup.expert.ASNLookupExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  Add ASN and netmask information from a local BGP dump

  static check(parameters)

    The bot’s own check function can perform individual checks on it’s parameters. init() is not called before, this is a staticmethod which does not require class initialization.

    Parameters

      parameters – Bot’s parameters, defaults and runtime merged together

    Returns

      None or a list of [log_level, log_message] pairs, both

        strings. log_level must be a valid log level.

    Return type

      output

  database = None
  init()
  process()
  classmethod run(parsed_args=None)
  classmethod update_database(verbose=False)

intelmq.bots.experts.asn_lookup.expert.BOT

  alias of `intelmq.bots.experts.asn_lookup.expert.ASNLookupExpertBot`

## Module contents